@@ -1,6 +1,6 @@
 
-/* GnomeMeeting -- A Video-Conferencing application
- * Copyright (C) 2000-2003 Damien Sandras
+/* GnomeMeeting --  Video-Conferencing application
+ * Copyright (C) 2000-2004 Damien Sandras
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@
  *                         druid.cpp  -  description
  *                         --------------------------
  *   begin                : Mon May 1 2002
- *   copyright            : (C) 2000-2003 by Damien Sandras
+ *   copyright            : (C) 2000-2004 by Damien Sandras
  *   description          : This file contains all the functions needed to
  *                          build the druid.
  */
@@ -175,7 +175,7 @@ gnomemeeting_druid_cancel (GtkWidget *w, gpointer data)
   dw = GnomeMeeting::Process ()->GetDruidWindow ();
   
   gnome_druid_set_page (dw->druid, GNOME_DRUID_PAGE (dw->page_edge));
-  gtk_widget_hide (gw->druid_window);
+  gnomemeeting_window_hide (gw->druid_window);
   gnomemeeting_window_show (gm);
 }
 
@@ -183,7 +183,7 @@ gnomemeeting_druid_cancel (GtkWidget *w, gpointer data)
 /* DESCRIPTION  :  This callback is called when the user clicks on finish.
  * BEHAVIOR     :  Destroys the druid, update gconf settings and update
  *                 the internal structures for devices and the corresponding
- *                 prefs window menus.
+ *                 prefs window menus. Displays a welcome message.
  * PRE          :  /
  */
 static void 
@@ -196,6 +196,7 @@ gnomemeeting_druid_quit (GtkWidget *w, gpointer data)
   
   GtkWidget *active_item = NULL;
   int item_index = 0;
+  int version = 0;
 
   BOOL has_video_device = FALSE;
   
@@ -239,14 +240,14 @@ gnomemeeting_druid_quit (GtkWidget *w, gpointer data)
   if (!gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dw->use_callto))
       && mail) {
 
-    if (!gconf_get_bool (LDAP_KEY "register"))
-      gconf_set_bool (LDAP_KEY "register", TRUE);
+    if (!gconf_get_bool (LDAP_KEY "enable_registering"))
+      gconf_set_bool (LDAP_KEY "enable_registering", TRUE);
     else
       ep->ILSRegister ();
   }
   else {
 
-    gconf_set_bool (LDAP_KEY "register", FALSE);
+    gconf_set_bool (LDAP_KEY "enable_registering", FALSE);
   }
   
 
@@ -271,46 +272,49 @@ gnomemeeting_druid_quit (GtkWidget *w, gpointer data)
   /* Dialup */
   if (item_index == 1) {
     
-    gconf_set_int (VIDEO_SETTINGS_KEY "tr_fps", 1);
-    gconf_set_int (VIDEO_SETTINGS_KEY "tr_vq", 1);
-    gconf_set_int (VIDEO_SETTINGS_KEY "maximum_video_bandwidth", 1);
-    gconf_set_bool (VIDEO_SETTINGS_KEY "enable_video_transmission", FALSE);
-    gconf_set_bool (VIDEO_SETTINGS_KEY "enable_video_reception", FALSE);
+    gconf_set_int (VIDEO_CODECS_KEY "transmitted_fps", 1);
+    gconf_set_int (VIDEO_CODECS_KEY "transmitted_video_quality", 1);
+    gconf_set_int (VIDEO_CODECS_KEY "maximum_video_bandwidth", 1);
+    gconf_set_bool (VIDEO_CODECS_KEY "enable_video_transmission", FALSE);
+    gconf_set_bool (VIDEO_CODECS_KEY "enable_video_reception", FALSE);
   }
   else if (item_index == 2) { /* ISDN */
     
-    gconf_set_int (VIDEO_SETTINGS_KEY "tr_fps", 2);
-    gconf_set_int (VIDEO_SETTINGS_KEY "tr_vq", 10);
-    gconf_set_int (VIDEO_SETTINGS_KEY "maximum_video_bandwidth", 2);
-    gconf_set_bool (VIDEO_SETTINGS_KEY "enable_video_transmission",
-		    has_video_device);
-    gconf_set_bool (VIDEO_SETTINGS_KEY "enable_video_reception", TRUE);
+    gconf_set_int (VIDEO_CODECS_KEY "transmitted_fps", 1);
+    gconf_set_int (VIDEO_CODECS_KEY "transmitted_video_quality", 1);
+    gconf_set_int (VIDEO_CODECS_KEY "maximum_video_bandwidth", 2);
+    gconf_set_bool (VIDEO_CODECS_KEY "enable_video_transmission", FALSE);
+    gconf_set_bool (VIDEO_CODECS_KEY "enable_video_reception", FALSE);
   }
   else if (item_index == 3) { /* DSL / CABLE */
     
-    gconf_set_int (VIDEO_SETTINGS_KEY "tr_fps", 8);
-    gconf_set_int (VIDEO_SETTINGS_KEY "tr_vq", 60);
-    gconf_set_int (VIDEO_SETTINGS_KEY "maximum_video_bandwidth", 8);
-    gconf_set_bool (VIDEO_SETTINGS_KEY "enable_video_transmission",
+    gconf_set_int (VIDEO_CODECS_KEY "transmitted_fps", 8);
+    gconf_set_int (VIDEO_CODECS_KEY "transmitted_video_quality", 60);
+    gconf_set_int (VIDEO_CODECS_KEY "maximum_video_bandwidth", 8);
+    gconf_set_bool (VIDEO_CODECS_KEY "enable_video_transmission",
 		    has_video_device);
-    gconf_set_bool (VIDEO_SETTINGS_KEY "enable_video_reception", TRUE);
+    gconf_set_bool (VIDEO_CODECS_KEY "enable_video_reception", TRUE);
   }
   else if (item_index == 4) { /* LDAN */
     
-    gconf_set_int (VIDEO_SETTINGS_KEY "tr_fps", 20);
-    gconf_set_int (VIDEO_SETTINGS_KEY "tr_vq", 80);
-    gconf_set_int (VIDEO_SETTINGS_KEY "maximum_video_bandwidth", 100);
-    gconf_set_bool (VIDEO_SETTINGS_KEY "enable_video_transmission",
+    gconf_set_int (VIDEO_CODECS_KEY "transmitted_fps", 20);
+    gconf_set_int (VIDEO_CODECS_KEY "transmitted_video_quality", 80);
+    gconf_set_int (VIDEO_CODECS_KEY "maximum_video_bandwidth", 100);
+    gconf_set_bool (VIDEO_CODECS_KEY "enable_video_transmission",
 		    has_video_device);
-    gconf_set_bool (VIDEO_SETTINGS_KEY "enable_video_reception", TRUE);
+    gconf_set_bool (VIDEO_CODECS_KEY "enable_video_reception", TRUE);
   }  
 
   g_timeout_add (2000, (GtkFunction) kind_of_net_hack,
 		 GINT_TO_POINTER (item_index));
 
-
+  
+  /* Set User Name and Alias */
+  ep->SetUserNameAndAlias ();
+  
+  
   /* Hide the druid and show GnomeMeeting */
-  gtk_widget_hide_all (GTK_WIDGET (gw->druid_window));
+  gnomemeeting_window_hide (GTK_WIDGET (gw->druid_window));
   gnome_druid_set_page (dw->druid, GNOME_DRUID_PAGE (dw->page_edge));
   gnomemeeting_window_show (gm);
 
@@ -319,6 +323,18 @@ gnomemeeting_druid_quit (GtkWidget *w, gpointer data)
      if the manager doesn't change */
   GnomeMeeting::Process ()->DetectDevices ();  
   gnomemeeting_pref_window_update_devices_list ();
+  
+
+  /* Displays a welcome message */
+  if (gconf_get_int (GENERAL_KEY "version") 
+      < MAJOR_VERSION * 1000 + MINOR_VERSION * 10 + BUILD_NUMBER)
+    gnomemeeting_message_dialog (GTK_WINDOW (gm), _("Welcome to GnomeMeeting 1.00!"), _("Congratulations, you have just successfully launched GnomeMeeting 1.00 for the first time.\nGnomeMeeting is the leading VoIP, videoconferencing and telephony software for Unix.\n\nThanks to all of you who have helped us along the road to our golden 1.00 release!\n\nThe GnomeMeeting Team."));
+
+  
+  /* Update the version number */
+  version = MAJOR_VERSION*1000+MINOR_VERSION*10+BUILD_NUMBER;
+    
+  gconf_set_int (GENERAL_KEY "version", version);
 }
 
 
@@ -523,6 +539,8 @@ gnomemeeting_druid_page_prepare (GnomeDruidPage *page,
   GmWindow *gw = NULL;
   GmDruidWindow *dw = NULL;
 
+  GMH323EndPoint *ep = NULL;
+  
   gchar *name = NULL;
   gchar *firstname = NULL;
   gchar *lastname = NULL;
@@ -555,6 +573,7 @@ gnomemeeting_druid_page_prepare (GnomeDruidPage *page,
   
   dw = GnomeMeeting::Process ()->GetDruidWindow ();
   gw = GnomeMeeting::Process ()->GetMainWindow ();
+  ep = GnomeMeeting::Process ()->Endpoint ();
 
   if (GPOINTER_TO_INT (data) == 1) {
     
@@ -570,7 +589,7 @@ gnomemeeting_druid_page_prepare (GnomeDruidPage *page,
     lastname = gconf_get_string (PERSONAL_DATA_KEY "lastname");
     mail = gconf_get_string (PERSONAL_DATA_KEY "mail");
     kind_of_net = gconf_get_int (GENERAL_KEY "kind_of_net");
-    ils_register = gconf_get_bool (LDAP_KEY "register");
+    ils_register = gconf_get_bool (LDAP_KEY "enable_registering");
 
     
     if (!strcmp (gtk_entry_get_text (GTK_ENTRY (dw->name)), "")) {
@@ -639,8 +658,11 @@ gnomemeeting_druid_page_prepare (GnomeDruidPage *page,
     recorder = gconf_get_string (AUDIO_DEVICES_KEY "input_device");
     
     gnomemeeting_sound_daemons_suspend ();
-    devices = PSoundChannel::GetDeviceNames (audio_manager,
-					     PSoundChannel::Player);
+    if (PString ("Quicknet") == audio_manager)
+      devices = OpalIxJDevice::GetDeviceNames ();
+    else
+      devices = PSoundChannel::GetDeviceNames (audio_manager,
+					       PSoundChannel::Player);
     if (devices.GetSize () == 0) {
 
       devices += PString (_("No device found"));
@@ -653,8 +675,11 @@ gnomemeeting_druid_page_prepare (GnomeDruidPage *page,
     option_menu_update (dw->audio_player, array, player);
     free (array);
 
-    devices = PSoundChannel::GetDeviceNames (audio_manager,
-					     PSoundChannel::Recorder);
+    if (PString ("Quicknet") == audio_manager)
+      devices = OpalIxJDevice::GetDeviceNames ();
+    else
+      devices = PSoundChannel::GetDeviceNames (audio_manager,
+					       PSoundChannel::Recorder);
     if (devices.GetSize () == 0) {
 
       devices += PString (_("No device found"));
@@ -672,6 +697,9 @@ gnomemeeting_druid_page_prepare (GnomeDruidPage *page,
     
     g_free (player);
     g_free (recorder);
+
+    if (ep->GetCallingState () != GMH323EndPoint::Standby)
+      gtk_widget_set_sensitive (GTK_WIDGET (dw->audio_test_button), FALSE);
   }
   else if (GPOINTER_TO_INT (data) == 8) {
 
@@ -688,7 +716,7 @@ gnomemeeting_druid_page_prepare (GnomeDruidPage *page,
 	
     video_recorder = gconf_get_string (VIDEO_DEVICES_KEY "input_device");
     
-    devices = PVideoInputDevice::GetDeviceNames (video_manager);
+    devices = PVideoInputDevice::GetDriversDeviceNames (video_manager);
 
     if (devices.GetSize () == 0) {
 
@@ -705,6 +733,9 @@ gnomemeeting_druid_page_prepare (GnomeDruidPage *page,
     gdk_window_set_cursor (GTK_WIDGET (gw->druid_window)->window, NULL);
    
     g_free (recorder);
+
+    if (ep->GetCallingState () != GMH323EndPoint::Standby)
+      gtk_widget_set_sensitive (GTK_WIDGET (dw->video_test_button), FALSE);
   }
   else if (GPOINTER_TO_INT (data) == 9) {
 
@@ -714,7 +745,7 @@ gnomemeeting_druid_page_prepare (GnomeDruidPage *page,
     callto_url = g_strdup_printf ("callto:ils.seconix.com/%s",
 				  mail ? mail : "");
     
-    text = g_strdup_printf (_("You have now finished the GnomeMeeting configuration. All the settings can be changed in the GnomeMeeting preferences. Enjoy!\n\n\nConfiguration Summary:\n\nUsername:  %s\nConnection type:  %s\nAudio manager: %s\nAudio player:  %s\nAudio recorder:  %s\nVideo Manager: %s\nVideo player: %s\nMy Callto URL: %s\n"), name, connection_type, audio_manager, player, recorder, video_manager, video_recorder, !gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dw->use_callto)) ? callto_url : _("None"));
+    text = g_strdup_printf (_("You have now finished the GnomeMeeting configuration. All the settings can be changed in the GnomeMeeting preferences. Enjoy!\n\n\nConfiguration summary:\n\nUsername:  %s\nConnection type:  %s\nAudio manager: %s\nAudio player:  %s\nAudio recorder:  %s\nVideo manager: %s\nVideo player: %s\nCallto URL: %s\n"), name, connection_type, audio_manager, player, recorder, video_manager, video_recorder, !gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dw->use_callto)) ? callto_url : _("None"));
     gnome_druid_page_edge_set_text (GNOME_DRUID_PAGE_EDGE (page), text);
 
     g_free (callto_url);
@@ -756,7 +787,7 @@ gnomemeeting_init_druid_personal_data_page (GnomeDruid *druid, int p, int t)
 
   
   /* The user fields */
-  label = gtk_label_new (_("Please enter your firstname and your surname:"));
+  label = gtk_label_new (_("Please enter your first name and your surname:"));
   gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
   gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
 
@@ -764,7 +795,7 @@ gnomemeeting_init_druid_personal_data_page (GnomeDruid *druid, int p, int t)
   gtk_box_pack_start (GTK_BOX (vbox), dw->name, FALSE, FALSE, 0);
 
   label = gtk_label_new (NULL);
-  text = g_strdup_printf ("<i>%s</i>", _("Your firstname and surname will be used when connecting to other VoIP and videoconferencing software."));
+  text = g_strdup_printf ("<i>%s</i>", _("Your first name and surname will be used when connecting to other VoIP and videoconferencing software."));
   gtk_label_set_markup (GTK_LABEL (label), text);
   g_free (text);
   gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
@@ -1056,7 +1087,7 @@ gnomemeeting_init_druid_audio_devices_page (GnomeDruid *druid,
 
   align = gtk_alignment_new (1.0, 0, 0, 0);
   dw->audio_test_button =
-    gtk_toggle_button_new_with_label (_("Test those settings"));
+    gtk_toggle_button_new_with_label (_("Test Settings"));
   gtk_container_add (GTK_CONTAINER (align), dw->audio_test_button);
   gtk_box_pack_start (GTK_BOX (vbox), align, FALSE, FALSE, 0);
   
@@ -1194,7 +1225,7 @@ gnomemeeting_init_druid_video_devices_page (GnomeDruid *druid,
 
   align = gtk_alignment_new (1.0, 0, 0, 0);
   dw->video_test_button =
-    gtk_toggle_button_new_with_label (_("Test those settings"));
+    gtk_toggle_button_new_with_label (_("Test Settings"));
   gtk_container_add (GTK_CONTAINER (align), dw->video_test_button);
   gtk_box_pack_start (GTK_BOX (vbox), align, FALSE, FALSE, 0);
   
@@ -1225,6 +1256,9 @@ gnomemeeting_druid_window_new (GmDruidWindow *dw)
   GnomeDruidPageEdge *page_final = NULL;
   
   window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+  g_object_set_data_full (G_OBJECT (window), "window_name",
+			  g_strdup ("druid_window"), g_free); 
+  
   gtk_window_set_title (GTK_WINDOW (window), 
 			_("First Time Configuration Druid"));
   gtk_window_set_position (GTK_WINDOW (window), GTK_WIN_POS_CENTER);
